(function() {
    "use strict";

    /**
     * Queries holds all the query object entity used within mdApp.
     * Queries should only used by Endpoints service to centralize the control, with the exception to PermissionService
     * used for auto checking FLS on the object and fields defined here.
     */
    angular.module("weChatApp")
        .value("Queries", {
            userById: {
                object: "User",
                fields: ["Id", "Name", "LanguageLocaleKey", "LocaleSidKey", "TimeZoneSidKey"],
                where: "Id = _id"
            },
            territoryByUserId: {
                object: "UserTerritory",
                fields: ["TerritoryId"],
                where: "UserId = _userId AND IsActive = _true"
            },
            territory: {
                object: "Territory",
                fields: ["Id", "ParentTerritoryId", "Name"]
            },
            territoryGroupByRelatedIds: {
                object: 'Group',
                fields: ['Id', 'RelatedId'],
                where: 'Type = \'Territory\' AND RelatedId IN '
            },
            accountShareByGroupIds: {
                object: 'AccountShare',
                fields: ['Id', 'AccountId', 'UserOrGroupId'],
                where: 'UserOrGroupId IN '
            },
            sentMessagesByUser: {
                object: "Sent_Message_vod__c",
                fields: ["Id", "OwnerId", "Account_vod__c", "Content_vod__c", "Sent_Datetime_vod__c", "Opened_vod__c",
                    "Last_Open_Datetime_vod__c", "Service_Account_vod_del__c", "Total_Duration_vod__c",
                    "Content_Clicked_vod__c"],
                where: "OwnerId = _userId AND Sent_Datetime_vod__c >= _datetime1 AND Sent_Datetime_vod__c <= _datetime2"
            },
            multichannelConsentByAccountIds: {
                object: "Multichannel_Consent_vod__c",
                fields: ["Id", "Account_vod__c", "Opt_Type_vod__c", "Capture_Datetime_vod__c", "Consent_Confirm_Datetime_vod__c",
                    "Channel_Value_vod__c", "Opt_Expiration_Date_vod__c", "RecordTypeId"],
                where: "Capture_Datetime_vod__c >= _datetime1 AND Capture_Datetime_vod__c <= _datetime2 AND Account_vod__c IN "
            },
            accountByIds: {
                object: "Account",
                fields: ["Id", "Name"],
                where: "Id IN "
            },
            multichannelContentByIds: {
                object: "Multichannel_Content_vod__c",
                fields: ["Id", "Name"],
                where: "Id IN "
            },
            contentTypeByIds: {
                object: "Content_Type_vod__c",
                fields: ["Id", "Name"],
                where: "Id IN "
            },
            weChatRecordType: {
                object: 'RecordType',
                fields: ["Id", "DeveloperName", "SobjectType"],
                where: "SobjectType = \'Multichannel_Consent_vod__c\' AND DeveloperName = \'WeChat_vod\'"
            },
        })
    ;
}());
